@@ -14,11 +14,19 @@ use Coat::Meta;
 use Coat::Object;
 use Coat::Types;
 
-$VERSION   = '0.334';
+$VERSION   = '0.501';
 $AUTHORITY = 'cpan:SUKRIA';
 
 # our exported keywords for class description
-@EXPORT = qw(has extends before after around);
+@EXPORT = qw(
+    after 
+    alias
+    around
+    before 
+    extends 
+    has 
+    with 
+);
 
 # Prototypes for private methods
 sub _bind_coderef_to_symbol($$);
@@ -31,6 +39,19 @@ sub _build_sub_with_hook($$);
 # Public static methods
 ##############################################################################
 
+sub alias { 
+    my ($name, $method) = @_;
+    my $caller = caller;
+    { 
+        no strict 'refs';
+        my $orig = *{"${caller}::${method}"};
+        if (not defined &$orig) {
+            confess "cannot alias undefined method \"$method\"";
+        }
+        *{"${caller}::${name}"} = *{"${caller}::${method}"};
+    }
+}
+
 # has() declares an attribute and builds the corresponding accessors
 sub has {
     my ( $attr_name, %options ) = @_;
@@ -99,6 +120,23 @@ sub extends {
     _extends_class( \@mothers, getscope() );
 }
 
+sub with {
+    my (@roles) = @_;
+    my $caller   = caller;
+    my @methods  = Coat::Meta::_list_all_package_symbols($caller, 'CODE');
+
+    foreach my $role (@roles) {
+        my @requires = Coat::Meta->role_get_required_methods($role);
+        foreach my $required (@requires) {
+            confess ("Methods "
+                  . join(", ", @requires)
+                  . " are required by the role $role")
+                unless grep(/^$required$/, @methods);
+        }
+        Coat::Meta->compose_class_with_role($caller => $role);
+    }
+}
+
 # the before hook catches the call to an inherited method and exectue
 # the code given before the inherited method is called.
 sub before {
@@ -131,7 +169,7 @@ sub around {
 # modes to children and also to force the Coat::Object inheritance.
 sub import {
     my $caller = caller;
-    return if $caller eq 'main';
+    return if $caller eq 'main' or $caller eq 'Coat::Role';
     my $class_name = getscope();
 
     # import strict and warnings
@@ -270,6 +308,7 @@ sub _build_sub_with_hook($$) {
         my $coderef;
         { 
             no strict 'refs'; 
+            no warnings;
             $coderef = *{ "${parent_class}::${method}" };
         }
         $super = $parent_class if defined &$coderef;
@@ -356,7 +395,15 @@ __END__
 
 =head1 NAME
 
-Coat -- A light and self-dependent meta-class for Perl5
+Coat -- A light and self-dependent meta-class for Perl5 (DEPRECATED)
+
+=head1 DEPRECATION NOTICE
+
+This module has been deprecated. Please use some other metaclass-based
+object system for Perl 5. The following are recommended (though there are
+plenty other great ones): L<Moose>, L<Mouse>, L<Moo> and L<Mo>.
+
+Coat is no longer maintained.
 
 =head1 DESCRIPTION
 
@@ -478,6 +525,24 @@ updated value and the attribute meta-object (this is for more advanced fiddling
 and can typically be ignored). You B<cannot> have a trigger on a read-only
 attribute.
 
+=back
+
+=head2 ALIASES
+
+You can alias any method of a class with the keyword I<alias>, like in the
+following example:
+
+    package Foo;
+    use Coat;
+
+    sub foo { ... }
+    alias bar => 'foo';
+
+This will create a method I<bar> in the module's namespace that points to the
+same code reference as the one of the method I<foo>.
+
+You can alias any method defined in the namespace of the current class
+(including inherited methods and accessors).
 
 =head2 METHOD MODIFIERS (HOOKS)
 
